#
# spec file for package python-lmiwbem
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# doc generation segfaults :-/
%global with_doc 0

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python-lmiwbem
Version:        0.7.2
Release:        3.1
Summary:        Python WBEM Client
License:        LGPL-2.0+
Group:          System/Management
Url:            https://github.com/phatina/python-lmiwbem
Source0:        https://github.com/phatina/python-lmiwbem/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE, SUSE packages internal Pegasus include files in separate directory, kkaempf@suse.de
Patch1:         include-pegasus-internal.patch
# PATCH-FIX-OPENSUSE, build service reports (some) 32bit systems as 'athlon'
Patch2:         accept-athlon.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%if 0%{?suse_version}
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  python-devel
%else
BuildRequires:  boost-python >= 1.50.0
BuildRequires:  python2-devel
%endif
BuildRequires:  boost-devel > 1.50.0
BuildRequires:  openslp-devel
BuildRequires:  tog-pegasus-devel >= 2.12.0
BuildRequires:  tog-pegasus-libs >= 2.12.0
%if %{with_doc}
BuildRequires:  python-sphinx
BuildRequires:  python-sphinx_rtd_theme
BuildRequires:  python-sphinxcontrib-napoleon
%endif
BuildRequires:  libwsman_clientpp-devel

Provides:       lmiwbem = %{version}-%{release}
Obsoletes:      lmiwbem < 0.6.1-1

%description
%{name} is a Python library, which performs CIM operations using CIM-XML
protocol. The library tries to mimic PyWBEM.

%if %{with_doc}
%package doc
Summary:        Documentation for %{name}
Group:          Documentation

%description doc
%{summary}
%endif

%prep
%setup -q -n %{name}-%{version}
%if 0%{?suse_version}
%patch1 -p1
%patch2 -p1
%endif

%build
autoreconf -fi
%configure \
%if 0%{?suse_version}
--with-default-trust-store=/etc/pki/trust/anchors \
%endif
--with-wsman=yes \
%if %{with_doc}
--with-doc=yes
%endif

CPPFLAGS="-I /usr/include/Pegasus-internal" make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
find %{buildroot} -name '*.la' | xargs rm -f

%files
%defattr(-,root,root,-)
%doc COPYING README.md
%{python_sitearch}/lmiwbem/

%if %{with_doc}
%files doc
%defattr(-,root,root,-)
%dir %{_docdir}/%{name}-%{version}
%{_docdir}/%{name}-%{version}/html
%endif

%changelog
* Mon Jan 11 2016 kkaempf@suse.com
- Accept 'uname -p' reporting 'athlon'
  accept-athlon.patch
* Mon Jun 29 2015 kkaempf@suse.com
- enable WSMAN support
- Update to 0.7.2
  - fixed parameter compatibility in WBEMConnection.__init__() with PyWBEM
  - fixed lmiwbem.config modifications
  - improved exceptions handling
- Update to 0.7.1
  - fixed python3 build
  - fixed boost::python library checks
* Tue Feb 24 2015 kkaempf@suse.com
- Update to 0.7.0
  - renamed to *python-lmiwbem*
  - introduced WSMAN support
  - URLInfo redesigned for better error handling
  - various fixes and improvements
* Tue Jan 13 2015 kkaempf@suse.com
- Update to 0.6.0
  - WBEMConnection can parse username:password from URL
  - added *compatibility parameters* in pull operations
  - added missing CIM error constants for pull operations
  - lmiwbem.config object
  - DEFAULT_NAMESPACE
  - DEFAULT_TRUST_STORE
  - SUPPORTS_PULL_OPERATIONS
  - fixed overflow error for large int on 64-bit
  - proper hostname is set for local connections
  - unified string for whole code base
  - source tree reorganization
  - various fixes and improvements
* Fri Dec  5 2014 kkaempf@suse.com
- Update to 0.5.0
  - pull operations
  - fixed CIMIndicationListener port value, when multiple bind
    retries are allowed
  - fixed multithreading races
  - verbose exceptions (more informative exception message)
  - CIMError, ConnectionError can include intrinsic call names
    and their parameters
  - configurable via lmiwbem.EXCEPTION_VERBOSITY
  - CIMIndicationListener.add_handler() can take tuple of handlers
  - doc: switched to rtd theme
  - various fixes and improvements
* Wed Oct 29 2014 kkaempf@suse.com
- Update to 0.4.0
  - introduce WBEMConnection::setCredentials()
  - introduce LMIWBEM_UNREACHABLE macro for CIMValue::asLMIWbemCIMValue()
  - introduce WBEMConnection::setRequestAcceptLanguages()
  - add missing hostname property to CIMInstance(Name)
  - simplify WBEMConnection::createInstance()
  - introduce distutils as secondary build system
  - various fixes
* Tue Sep  2 2014 kkaempf@suse.com
- Update to 0.3.1
  - refactor exception handling in WBEMConnection's CIM methods
  - add property/parameter name to Pegasus::TypeMismatchException
  - set namespace for each CIMInstance when
    WBEMConnection::enumerateInstances() is called
* Thu May 22 2014 kkaempf@suse.com
- Update to 0.2.0
  * WBEMConnection:
  - AssociatorNames()
  - Associators()
  - CreateInstance()
  - DeleteInstance()
  - ExecQuery()
  - InvokeMethod()
  - ModifyInstance()
  - ReferenceNames()
  - References()
  - connectLocally()
  - CIM operation timeout
  - X509 authentication
  * CIMInstance(Name) classes: iteration methods
  * CIM* classes: cmp, copy, tomof
  * CIM constants
  - CIMError constants
  - ConnectionError constants
  - default namespace
  - default trust store path
  * CIMIndicationListener
  * is_subclass()
  * Python 2.6 and 3.x support
  * sphinx-based documentation
  * various fixes
- lmiwbem uses internal Pegasus include files, add the respective
  path to makefile.am (lmiwbem-0.2.0.patch)
* Tue May 13 2014 kkaempf@suse.com
- Initial version 0.1.0
